@@ -1,7 +1,6 @@
 import io
-import json
 
-import pytest
+import pytest  # type: ignore
 
 from json_streams import json_iter, jsonl_iter
 from .utils import compare_iters
@@ -12,13 +11,9 @@ DATA = [
     {"a": 2},
 ]
 
-JSON_FACIT = b'[\n{"a":1},\n{"a":2}\n]'
-JSONL_FACIT = b'{"a":1}\n{"a":2}\n'
-
 
 def gen_data():
-    for i in DATA:
-        yield i
+    yield from DATA
 
 
 @pytest.mark.parametrize(
